==> qt6-qtquick3d-6.8.3.tgz: lib/cmake/Qt6Quick3DTools/Qt6Quick3DToolsTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::balsam" for configuration "Release"
set_property(TARGET Qt6::balsam APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::balsam PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/balsam"
  )

list(APPEND _cmake_import_check_targets Qt6::balsam )
list(APPEND _cmake_import_check_files_for_Qt6::balsam "${_IMPORT_PREFIX}/lib/qt6/bin/balsam" )

# Import target "Qt6::balsamui" for configuration "Release"
set_property(TARGET Qt6::balsamui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::balsamui PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/balsamui"
  )

list(APPEND _cmake_import_check_targets Qt6::balsamui )
list(APPEND _cmake_import_check_files_for_Qt6::balsamui "${_IMPORT_PREFIX}/lib/qt6/bin/balsamui" )

# Import target "Qt6::meshdebug" for configuration "Release"
set_property(TARGET Qt6::meshdebug APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::meshdebug PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/meshdebug"
  )

list(APPEND _cmake_import_check_targets Qt6::meshdebug )
list(APPEND _cmake_import_check_files_for_Qt6::meshdebug "${_IMPORT_PREFIX}/lib/qt6/bin/meshdebug" )

# Import target "Qt6::shadergen" for configuration "Release"
set_property(TARGET Qt6::shadergen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::shadergen PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/shadergen"
  )

list(APPEND _cmake_import_check_targets Qt6::shadergen )
list(APPEND _cmake_import_check_files_for_Qt6::shadergen "${_IMPORT_PREFIX}/lib/qt6/bin/shadergen" )

# Import target "Qt6::instancer" for configuration "Release"
set_property(TARGET Qt6::instancer APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::instancer PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/instancer"
  )

list(APPEND _cmake_import_check_targets Qt6::instancer )
list(APPEND _cmake_import_check_files_for_Qt6::instancer "${_IMPORT_PREFIX}/lib/qt6/bin/instancer" )

# Import target "Qt6::shapegen" for configuration "Release"
set_property(TARGET Qt6::shapegen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::shapegen PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/shapegen"
  )

list(APPEND _cmake_import_check_targets Qt6::shapegen )
list(APPEND _cmake_import_check_files_for_Qt6::shapegen "${_IMPORT_PREFIX}/lib/qt6/bin/shapegen" )

# Import target "Qt6::materialeditor" for configuration "Release"
set_property(TARGET Qt6::materialeditor APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::materialeditor PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/materialeditor"
  )

list(APPEND _cmake_import_check_targets Qt6::materialeditor )
list(APPEND _cmake_import_check_files_for_Qt6::materialeditor "${_IMPORT_PREFIX}/lib/qt6/bin/materialeditor" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> qt6-qtquick3d-6.10.1.tgz: lib/cmake/Qt6Quick3DTools/Qt6Quick3DToolsTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::balsam" for configuration "Release"
set_property(TARGET Qt6::balsam APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::balsam PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/balsam"
  )

list(APPEND _cmake_import_check_targets Qt6::balsam )
list(APPEND _cmake_import_check_files_for_Qt6::balsam "${_IMPORT_PREFIX}/lib/qt6/bin/balsam" )

# Import target "Qt6::balsamui" for configuration "Release"
set_property(TARGET Qt6::balsamui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::balsamui PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/balsamui"
  )

list(APPEND _cmake_import_check_targets Qt6::balsamui )
list(APPEND _cmake_import_check_files_for_Qt6::balsamui "${_IMPORT_PREFIX}/lib/qt6/bin/balsamui" )

# Import target "Qt6::meshdebug" for configuration "Release"
set_property(TARGET Qt6::meshdebug APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::meshdebug PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/meshdebug"
  )

list(APPEND _cmake_import_check_targets Qt6::meshdebug )
list(APPEND _cmake_import_check_files_for_Qt6::meshdebug "${_IMPORT_PREFIX}/lib/qt6/bin/meshdebug" )

# Import target "Qt6::shadergen" for configuration "Release"
set_property(TARGET Qt6::shadergen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::shadergen PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/shadergen"
  )

list(APPEND _cmake_import_check_targets Qt6::shadergen )
list(APPEND _cmake_import_check_files_for_Qt6::shadergen "${_IMPORT_PREFIX}/lib/qt6/bin/shadergen" )

# Import target "Qt6::instancer" for configuration "Release"
set_property(TARGET Qt6::instancer APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::instancer PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/instancer"
  )

list(APPEND _cmake_import_check_targets Qt6::instancer )
list(APPEND _cmake_import_check_files_for_Qt6::instancer "${_IMPORT_PREFIX}/lib/qt6/bin/instancer" )

# Import target "Qt6::shapegen" for configuration "Release"
set_property(TARGET Qt6::shapegen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::shapegen PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/shapegen"
  )

list(APPEND _cmake_import_check_targets Qt6::shapegen )
list(APPEND _cmake_import_check_files_for_Qt6::shapegen "${_IMPORT_PREFIX}/lib/qt6/bin/shapegen" )

# Import target "Qt6::materialeditor" for configuration "Release"
set_property(TARGET Qt6::materialeditor APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::materialeditor PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/materialeditor"
  )

list(APPEND _cmake_import_check_targets Qt6::materialeditor )
list(APPEND _cmake_import_check_files_for_Qt6::materialeditor "${_IMPORT_PREFIX}/lib/qt6/bin/materialeditor" )

# Import target "Qt6::lightmapviewer" for configuration "Release"
set_property(TARGET Qt6::lightmapviewer APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::lightmapviewer PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/qt6/bin/lightmapviewer"
  )

list(APPEND _cmake_import_check_targets Qt6::lightmapviewer )
list(APPEND _cmake_import_check_files_for_Qt6::lightmapviewer "${_IMPORT_PREFIX}/lib/qt6/bin/lightmapviewer" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
